@@ -19,6 +19,7 @@ import options_storage
 
 BASE_STAGE = "construction"
 READS_TYPES_USED_IN_CONSTRUCTION = ["paired-end", "single", "hq-mate-pairs"]
+READS_TYPES_USED_IN_RNA_SEQ = ["paired-end", "single", "trusted-contigs", "untrusted-contigs"]
 
 
 def prepare_config_spades(filename, cfg, log, additional_contigs_fname, K, stage, saves_dir, last_one, execution_home):
@@ -94,13 +95,13 @@ def update_k_mers_in_special_cases(cur_k_mers, RL, log, silent=False):
         if RL >= 150:
             if not silent:
                 log.info("Default k-mer sizes were set to %s because estimated "
-                         "read length (%d) is equal to or greater than 150" % (str(options_storage.K_MERS_150), RL), log)
+                         "read length (%d) is equal to or greater than 150" % (str(options_storage.K_MERS_150), RL))
             return options_storage.K_MERS_150
     if RL <= max(cur_k_mers):
         new_k_mers = [k for k in cur_k_mers if k < RL]
         if not silent:
             log.info("K-mer sizes were set to %s because estimated "
-                     "read length (%d) is less than %d" % (str(new_k_mers), RL, max(cur_k_mers)), log)
+                     "read length (%d) is less than %d" % (str(new_k_mers), RL, max(cur_k_mers)))
         return new_k_mers
     return cur_k_mers
 
@@ -339,26 +340,35 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
             result_before_rr_contigs = os.path.join(os.path.dirname(cfg.result_contigs), "before_rr.fasta")
             if not os.path.isfile(result_before_rr_contigs) or not options_storage.continue_mode:
                 shutil.copyfile(os.path.join(latest, "before_rr.fasta"), result_before_rr_contigs)
-        if os.path.isfile(os.path.join(latest, "final_contigs.fasta")):
-            if not os.path.isfile(cfg.result_contigs) or not options_storage.continue_mode:
-                shutil.copyfile(os.path.join(latest, "final_contigs.fasta"), cfg.result_contigs)
-        if os.path.isfile(os.path.join(latest, "first_pe_contigs.fasta")):
-            result_first_pe_contigs = os.path.join(os.path.dirname(cfg.result_contigs), "first_pe_contigs.fasta")
-            if not os.path.isfile(result_first_pe_contigs) or not options_storage.continue_mode:
-                shutil.copyfile(os.path.join(latest, "first_pe_contigs.fasta"), result_first_pe_contigs)
-        if cfg.rr_enable:
-            if os.path.isfile(os.path.join(latest, "scaffolds.fasta")):
-                if not os.path.isfile(cfg.result_scaffolds) or not options_storage.continue_mode:
-                    shutil.copyfile(os.path.join(latest, "scaffolds.fasta"), cfg.result_scaffolds)
-        if os.path.isfile(os.path.join(latest, "assembly_graph.fastg")):
-            if not os.path.isfile(cfg.result_graph) or not options_storage.continue_mode:
-                shutil.copyfile(os.path.join(latest, "assembly_graph.fastg"), cfg.result_graph)
-        if os.path.isfile(os.path.join(latest, "final_contigs.paths")):
-            if not os.path.isfile(cfg.result_contigs_paths) or not options_storage.continue_mode:
-                shutil.copyfile(os.path.join(latest, "final_contigs.paths"), cfg.result_contigs_paths)
-        if os.path.isfile(os.path.join(latest, "scaffolds.paths")):
-            if not os.path.isfile(cfg.result_scaffolds_paths) or not options_storage.continue_mode:
-                shutil.copyfile(os.path.join(latest, "scaffolds.paths"), cfg.result_scaffolds_paths)
+        if options_storage.rna:
+            if os.path.isfile(os.path.join(latest, "transcripts.fasta")):
+                    if not os.path.isfile(cfg.result_transcripts) or not options_storage.continue_mode:
+                        shutil.copyfile(os.path.join(latest, "transcripts.fasta"), cfg.result_transcripts)
+            if os.path.isfile(os.path.join(latest, "transcripts.paths")):
+                if not os.path.isfile(cfg.result_transcripts_paths) or not options_storage.continue_mode:
+                    shutil.copyfile(os.path.join(latest, "transcripts.paths"), cfg.result_transcripts_paths)
+        else:
+            if os.path.isfile(os.path.join(latest, "final_contigs.fasta")):
+                if not os.path.isfile(cfg.result_contigs) or not options_storage.continue_mode:
+                    shutil.copyfile(os.path.join(latest, "final_contigs.fasta"), cfg.result_contigs)
+            if os.path.isfile(os.path.join(latest, "first_pe_contigs.fasta")):
+                result_first_pe_contigs = os.path.join(os.path.dirname(cfg.result_contigs), "first_pe_contigs.fasta")
+                if not os.path.isfile(result_first_pe_contigs) or not options_storage.continue_mode:
+                    shutil.copyfile(os.path.join(latest, "first_pe_contigs.fasta"), result_first_pe_contigs)
+            if cfg.rr_enable:
+                if os.path.isfile(os.path.join(latest, "scaffolds.fasta")):
+                    if not os.path.isfile(cfg.result_scaffolds) or not options_storage.continue_mode:
+                        shutil.copyfile(os.path.join(latest, "scaffolds.fasta"), cfg.result_scaffolds)
+                if os.path.isfile(os.path.join(latest, "scaffolds.paths")):
+                    if not os.path.isfile(cfg.result_scaffolds_paths) or not options_storage.continue_mode:
+                        shutil.copyfile(os.path.join(latest, "scaffolds.paths"), cfg.result_scaffolds_paths)
+            if os.path.isfile(os.path.join(latest, "assembly_graph.fastg")):
+                if not os.path.isfile(cfg.result_graph) or not options_storage.continue_mode:
+                    shutil.copyfile(os.path.join(latest, "assembly_graph.fastg"), cfg.result_graph)
+            if os.path.isfile(os.path.join(latest, "final_contigs.paths")):
+                if not os.path.isfile(cfg.result_contigs_paths) or not options_storage.continue_mode:
+                    shutil.copyfile(os.path.join(latest, "final_contigs.paths"), cfg.result_contigs_paths)
+
 
     if cfg.developer_mode:
         # saves
